OC.L10N.register(
    "news",
    {
    "Download" : "Yuklab olish",
    "Close" : "Yopish",
    "Folder name" : "Folder name",
    "Username" : "Username",
    "Password" : "Password",
    "New folder" : "New folder",
    "Credentials" : "Hisob ma'lumotlari",
    "Subscribe" : "Obuna boʻlish",
    "Move" : "Move",
    "Share" : "Ulashish",
    "Default" : "Standart",
    "Off" : "Oʻchirilgan",
    "Settings" : "Sozlamalar",
    "Documentation" : "Hujjatlar",
    "Keyboard shortcuts" : "Klaviatura yorliqlari",
    "Rename" : "Nomini o'zgartirish",
    "Delete" : "O'chirish",
    "Title" : "Sarlavha",
    "Not available" : "Mavjud emas",
    "right" : "right",
    "left" : "left",
    "Refresh" : "Refresh"
},
"nplurals=1; plural=0;");
